Imports MSXML2

Public Class EmployeeContentHandler
    Implements IVBSAXContentHandler

    ' Raise this event when we finish processing an Employee.
    Public Event EmployeeDone(ByVal last_name As String, ByVal first_name As String, ByVal phone As String)

    ' The current Employee's information.
    Private m_LastName As String
    Private m_FirstName As String
    Private m_Phone As String

    ' The name of the element we are reading.
    Private m_CurrentElementName As String

    ' documentLocator is the first method called when the SAX reader
    ' opens the XML document. Because this is the first event, it is
    ' a good place to initialize the class.
    ' 
    ' The parameter Value provides access to the XML document.
    Overridable WriteOnly Property CatchDocumentLocator() As IVBSAXLocator _
    Implements IVBSAXContentHandler.documentLocator
        Set(ByVal Value As IVBSAXLocator)

        End Set
    End Property

    ' startDocument is called when the SAX reader 
    ' starts reading the document.
    Overridable Sub CatchStartDocument() _
    Implements IVBSAXContentHandler.startDocument

    End Sub

    ' endDocument is called when the SAX reader is done reading 
    ' the document, either because it has reached the end of the 
    ' document or because it had a fatal error.
    Overridable Sub CatchEndDocument() _
    Implements IVBSAXContentHandler.endDocument

    End Sub

    ' startElement is called when the SAX reader 
    ' reads start of an element.
    Overridable Sub CatchStartElement( _
        ByRef strNamespaceURI As String, _
        ByRef strLocalName As String, _
        ByRef strQName As String, _
        ByVal oAttributes As MSXML2.IVBSAXAttributes) _
    Implements IVBSAXContentHandler.startElement
        ' See what kind of element this is.
        Select Case strLocalName
            Case "Employee"
                ' Reset the Employee's information.
                m_LastName = ""
                m_FirstName = ""
                m_Phone = ""
            Case "LastName"
                ' Prepare to read LastName.
                m_CurrentElementName = "LastName"
            Case "FirstName"
                ' Prepare to read FirstName.
                m_CurrentElementName = "FirstName"
            Case "Phone"
                ' See if Type = Work.
                If oAttributes.getValueFromName("", "Type") = "Work" Then
                    m_CurrentElementName = "Phone"
                Else
                    m_CurrentElementName = ""
                End If
            Case Else
                m_CurrentElementName = ""
        End Select
    End Sub

    ' endElement is called when the SAX reader 
    ' reads an element's closing tag.
    Overridable Sub CatchEndElement( _
        ByRef strNamespaceURI As String, _
        ByRef strLocalName As String, _
        ByRef strQName As String) _
    Implements IVBSAXContentHandler.endElement
        ' See what kind of element this is.
        Select Case strLocalName
            Case "Employee"
                ' This is the end of an Employee element.
                ' Send out the Employee data.
                RaiseEvent EmployeeDone(m_LastName, m_FirstName, m_Phone)
            Case Else
                ' We're no longer reading something significant.
                m_CurrentElementName = ""
        End Select
    End Sub

    ' The characters method is passed the characters that appear
    ' between an element's start and end tags.
    Overridable Sub CatchCharacters(ByRef strChars As String) _
    Implements IVBSAXContentHandler.characters
        Select Case m_CurrentElementName
            Case "LastName"
                m_LastName = strChars
            Case "FirstName"
                m_FirstName = strChars
            Case "Phone"
                m_Phone = strChars
        End Select
    End Sub

    ' startPrefixMapping is called when a URI namespace prefix 
    ' mapping starts. Occurs after the startElement call for the 
    ' element that contains it but the order of the startPrefixMapping
    ' and corresponding endPrefixMapping is not guaranteed.
    Overridable Sub CatchStartPrefixMapping( _
        ByRef strPrefix As String, _
        ByRef strURI As String) _
    Implements IVBSAXContentHandler.startPrefixMapping

    End Sub

    ' endPrefixMapping is called when a URI namespace prefix 
    ' mapping is ending. Occurs after the endElement call for the 
    ' element that contains it but the order of the startPrefixMapping
    ' and corresponding endPrefixMapping is not guaranteed.
    Overridable Sub CatchEndPrefixMapping( _
        ByRef strPrefix As String) _
    Implements IVBSAXContentHandler.endPrefixMapping

    End Sub

    ' ignorableWhitespace is not called by SAX2 because SAX2 is
    ' non-validating .
    Overridable Sub CatchIgnorableWhitespace( _
        ByRef strChars As String) _
    Implements IVBSAXContentHandler.ignorableWhitespace

    End Sub

    ' processingInstruction is called when teh SAX reader reads
    ' a processing instruction.
    Overridable Sub CatchProcessingInstruction( _
        ByRef strTarget As String, _
        ByRef strData As String) _
    Implements IVBSAXContentHandler.processingInstruction

    End Sub

    ' skippedEntity is called when the SAX reader skips an external
    ' DTD declaration and when it skips an entity. It skips an entity
    ' when it did not read that entity's declaration, for example
    ' if the entitiy was defined in an external declaration.
    Overridable Sub CatchSkippedEntity( _
        ByRef strName As String) _
    Implements IVBSAXContentHandler.skippedEntity

    End Sub
End Class
